%global debug_package %{nil}

Name: skim
Version: 0.9.4
Release: 1%{?dist}
Summary: Fuzzy Finder in rust!

License: GPLv3+
URL: https://github.com/lotabout/skim
Source0: %{url}/archive/v%{version}/%{name}-%{version}.tar.gz

%if 0%{?el8}
%else
BuildRequires:  cargo >= 1.42
BuildRequires:  rust >= 1.42
%endif

%description
Half of our life is spent on navigation: files, lines, commands… You need
skim! It is a general fuzzy finder that saves you time.

It is blazingly fast as it reads the data source asynchronously.

skim provides a single executable: sk. Basically anywhere you would want to
use grep, try sk instead.


%prep
%autosetup -p1
%if 0%{?el8}
curl https://sh.rustup.rs -sSf | sh -s -- --profile minimal -y
%endif

# Set codegen-units to 1
sed -i '/\[profile.release\]/a codegen-units = 1' Cargo.toml

# Cleanup interpreters
sed -i -e '/^#!\//, 1d' shell/completion.*
sed -i -e '1d;2i#!/bin/bash' bin/sk-tmux


%install
export CARGO_PROFILE_RELEASE_BUILD_OVERRIDE_OPT_LEVEL=3

%if 0%{?el8}
$HOME/.cargo/bin/cargo install --root=%{buildroot}%{_prefix} --path=.
%else
cargo install --root=%{buildroot}%{_prefix} --path=.
%endif

rm -f %{buildroot}%{_prefix}/.crates.toml \
    %{buildroot}%{_prefix}/.crates2.json
strip %{buildroot}%{_bindir}/*

install -Dpm0755 bin/sk-tmux %{buildroot}%{_bindir}/sk-tmux

# Install man
install -Dpm0644 man/man1/sk-tmux.1 %{buildroot}%{_mandir}/man1/sk-tmux.1
install -Dpm0644 man/man1/sk.1 %{buildroot}%{_mandir}/man1/sk.1

# Install vim plugin
install -Dpm0644 plugin/skim.vim \
    %{buildroot}%{_datadir}/vim/vimfiles/plugin/skim.vim
    
install -Dpm0644 plugin/skim.vim \
    %{buildroot}%{_datadir}/nvim/site/plugin/skim.vim

# Install shell completion
install -Dpm0644 shell/completion.bash \
    %{buildroot}%{_datadir}/bash-completion/completions/sk
install -Dpm0644 shell/completion.zsh \
    %{buildroot}%{_datadir}/zsh/site-functions/_sk

# Install shell key bindings (not enabled)
install -Dpm0644 shell/key-bindings.bash %{buildroot}%{_datadir}/skim/shell/key-bindings.bash
install -Dpm0644 shell/key-bindings.fish %{buildroot}%{_datadir}/skim/shell/key-bindings.fish
install -Dpm0644 shell/key-bindings.zsh %{buildroot}%{_datadir}/skim/shell/key-bindings.zsh


%files
%license LICENSE
%doc README.md CHANGELOG.md
%{_bindir}/sk
%{_bindir}/sk-tmux
%{_mandir}/man1/*.1*
%{_datadir}/%{name}/
%{_datadir}/vim/vimfiles/plugin/*.vim
%{_datadir}/nvim/site/plugin/*.vim
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/sk
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_sk


%changelog
* Mon Feb 15 2021 Artem Polishchuk <ego.cordatus@gmail.com> - 0.9.4-1
- build(update): 0.9.4

* Mon Nov  2 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.9.3-1
- Update to 0.9.3

* Sat Oct 24 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.9.2-1
- build(update): 0.9.2

* Tue Oct 20 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.9.1-1
- build(update): 0.9.1

* Sun Oct 18 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.9.0-1
- build(update): 0.9.0

* Fri Aug 14 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.8.2-1
- Update to 0.8.2

* Thu Apr 02 2020 Artem Polishchuk <ego.cordatus@gmail.com> - 0.8.1-1
- Initial package
